@@ -1,10 +1,10 @@
 stocsy.1d <-
 function(scaling, driver.peak) {
-  pwd.n = paste(getwd(), "/Preprocessing_Data_", scaling, "/NormalizedTable.csv", sep="")
+  pwd.n = paste(getwd(), "/Preprocessing_Data_", scaling, "/ProcessedTable.csv", sep="")
   x <- read.csv(pwd.n, sep=",", header=TRUE)
   x.x <- x[,2:ncol(x)]
   rownames(x.x) <- x[,1]
-  x.t <- t(x.x)
+  x.t <- x.x
   mycor = cor(x.t, method=c("pearson"))
   library(gplots)
   pal = matrix(rich.colors(41), nrow=1)
@@ -20,9 +20,9 @@ function(scaling, driver.peak) {
 	}
   }
   plot(mycor[,driver.peak], type="h", col=col, xlab = "Variables", ylab = paste("Coefficient of correlation with ", rownames(x.x)[driver.peak], sep=""), main = paste("STOCSY 1D (", rownames(x.x)[driver.peak], ")", sep=""), ylim = c(-1,1))
-  text(mycor[,driver.peak], labels=rownames(x.x), cex=0.5, col=col)  
+  text(mycor[,driver.peak], labels=colnames(x.x), cex=0.5, col=col)  
   dirout = paste(getwd(), "/STOCSY_1D/", sep="")
   dir.create(dirout)
-  out = paste(dirout, "stocsy_1d_", rownames(x.x)[driver.peak], ".pdf", sep="")
+  out = paste(dirout, "stocsy_1d_", colnames(x.x)[driver.peak], ".pdf", sep="")
   dev.copy2pdf(file=out)
   }
